@@ -3,8 +3,8 @@ from typing import Optional
 
 from the_spymaster_solvers_client.structs.requests import LoadModelsRequest
 from the_spymaster_solvers_client.structs.responses import LoadModelsResponse
-from the_spymaster_util import wrap
 from the_spymaster_util.http_client import DEFAULT_RETRY_STRATEGY, BaseHttpClient
+from the_spymaster_util.logging import wrap
 from urllib3 import Retry
 
 from .structs import (
